@@ -7,4 +7,4 @@ def get_db(db_config):
         "json_file": lambda x: LocalJsonDb(x),
         "google_hosted_json_file": lambda x: GoogleJsonDb(x)
     }
-    return config_loaders[db_config["type"]](db_config)
+    return config_loaders[db_config["TYPE"]](db_config)
